pub struct Features { /* private fields */ }Expand description
All the features of standard and solana events as specified
in the wallet standard. These features are contained within a
crate::Wallet struct allowing to check if a wallet supports a certain
feature and also calling the callback functions to make requests to a browser wallet.
Implementations